@@ -283,9 +283,10 @@ class NavSoapClient():
         serialized_response = serialize_object(soap_response)
         return serialized_response
 
-    def deploy_unit(self, cust_no, site_code, rental_order, unit_id, move_date, billing_start, engine_hours):
+    def deploy_unit(self, cust_no, site_code, rental_order, unit_id, deploy_date, billing_start, engine_hours, billing_size):
         """
         Use this when a unit is deployed to a site, to set the unit on the rental order.
+        rental_order, unit_id, deploy_date, and billing_start require values, all else should be empty strings.
         """
         session = Session()
         session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
@@ -300,17 +301,19 @@ class NavSoapClient():
             siteCode = site_code,
             rentalOrderNo = rental_order,
             equipNo = unit_id,
-            deployDate = move_date,
+            deployDate = deploy_date,
             startDate = billing_start,
             engineHours = engine_hours,
+            billingCode = billing_size
         )
 
         serialized_response = serialize_object(soap_response)
         return serialized_response
 
-    def retrieve_unit(self, cust_no, site_code, rental_order, unit_id, move_date, billing_start, engine_hours):
+    def retrieve_unit(self, cust_no, site_code, rental_order, unit_id, retrieval_date, billing_end, engine_hours):
         """
         Use this when a unit is retrieved from a site, to remove the unit from the rental order.
+        rental_order, unit_id, retrieval_date, and billing_end require values, all else should be empty strings.
         """
         session = Session()
         session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
@@ -325,10 +328,36 @@ class NavSoapClient():
             siteCode = site_code,
             rentalOrderNo = rental_order,
             equipNo = unit_id,
-            returnDate = move_date,
-            endDate = billing_start,
+            returnDate = retrieval_date,
+            endDate = billing_end,
             engineHours = engine_hours,
         )
 
+        serialized_response = serialize_object(soap_response)
+        return serialized_response
+
+    def swap(self, cust_no, site_code, rental_order, retrieved_unit_id, deployed_unit_id, swap_date, return_field_office, size_swap, billing_size):
+        """
+        Use this when units are swapped.
+        """
+        session = Session()
+        session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
+
+        soap_service_url = self.nav_soap_service + \
+            self.nav_company + "/Codeunit/UnitMove"
+        client = Client(soap_service_url, transport=Transport(
+            session=session, cache=SqliteCache()))
+
+        soap_response = client.service.SwapEquip(
+            custNo = cust_no,
+            siteCode = site_code,
+            rentalOrderNo = rental_order,
+            oldEquipNo = retrieved_unit_id,
+            newEquipNo = deployed_unit_id,
+            swapDate = swap_date,
+            returnLocation = return_field_office,
+            isSiteSwap = size_swap,
+        )
+
         serialized_response = serialize_object(soap_response)
         return serialized_response
\ No newline at end of file
